@@ -25,10 +25,6 @@ diamonds <- ggplot2::diamonds |>
     depth_pct = depth
   )
 
-# Optional: sample 1000 rows so that the code executes faster.
-set.seed(0)
-diamonds_sample <- ggplot2::diamonds[sample(nrow(ggplot2::diamonds), 1000), ]
-
 summary(diamonds)
 
 ## ----diamonds_str-------------------------------------------------------------
@@ -49,7 +45,15 @@ summary(gam_diamonds)
 
 ## ----ale_simple---------------------------------------------------------------
 # Simple ALE without bootstrapping
-ale_gam_diamonds <- ALE(gam_diamonds)
+
+# # To generate the code, uncomment the following lines.
+# # For speed, this vignette loads a pre-created ALE object.
+# # For standard models like mgcv::gam that store their data,
+# # there is no need to specify the data argument.
+# ale_gam_diamonds <- ALE(gam_diamonds)
+# saveRDS(ale_gam_diamonds, file.choose())
+ale_gam_diamonds <- url('https://github.com/tripartio/ale/raw/main/download/ale_gam_diamonds.0.5.2.rds') |> 
+  readRDS()
 
 ## ----create-plots-------------------------------------------------------------
 # Print a plot by entering its reference
@@ -63,20 +67,19 @@ get(diamonds_plots, 'carat')
 # Print all plots
 plot(diamonds_plots, ncol = 2)
 
-## ----diamonds_new-------------------------------------------------------------
-# Bootstraping is rather slow, so create a smaller subset of new data for demonstration
-set.seed(0)
-new_rows <- sample(nrow(diamonds), 200, replace = FALSE)
-diamonds_small_test <- diamonds[new_rows, ]
-
 ## ----ale_boot, fig.width=7, fig.height=11-------------------------------------
 
-ale_gam_diamonds_boot <- ALE(
-  model = gam_diamonds, 
-  data = diamonds_small_test, 
-  # Normally boot_it should be set to at least 100, but just 10 here for a faster demonstration
-  boot_it = 10
-)
+# # To generate the code, uncomment the following lines.
+# # For speed, this vignette loads a pre-created ALE object.
+# # For standard models like mgcv::gam that store their data,
+# # there is no need to specify the data argument.
+# ale_gam_diamonds_boot <- ALE(
+#   gam_diamonds, 
+#   boot_it = 100
+# )
+# saveRDS(ale_gam_diamonds_boot, file.choose())
+ale_gam_diamonds_boot <- url('https://github.com/tripartio/ale/raw/main/download/ale_gam_diamonds_boot.0.5.2.rds') |> 
+  readRDS()
 
 # Bootstrapping produces confidence intervals
 plot(ale_gam_diamonds_boot) |> 
@@ -84,10 +87,19 @@ plot(ale_gam_diamonds_boot) |>
 
 ## ----ale_2D-------------------------------------------------------------------
 # ALE two-way interactions
-ale_2D_gam_diamonds <- ALE(
-  gam_diamonds,
-  x_cols = list(d2 = TRUE)
-)
+
+# # To generate the code, uncomment the following lines.
+# # For speed, this vignette loads a pre-created ALE object.
+# # For standard models like mgcv::gam that store their data,
+# # there is no need to specify the data argument.
+# ale_2D_gam_diamonds <- ALE(
+#   gam_diamonds,
+#   x_cols = list(d2 = TRUE)
+# )
+# saveRDS(ale_2D_gam_diamonds, file.choose())
+ale_2D_gam_diamonds <- url('https://github.com/tripartio/ale/raw/main/download/ale_2D_gam_diamonds.0.5.2.rds') |> 
+  readRDS()
+
 
 ## ----print-all-2D, fig.width=7, fig.height=7----------------------------------
 diamonds_2D_plots <- plot(ale_2D_gam_diamonds)
